@@ -1,5 +1,7 @@
 //! Module with the BresenhamZips and library logic
+pub use zip_x::BresenhamZipX;
 pub use zip_y::BresenhamZipY;
 
+mod error;
+mod zip_x;
 mod zip_y;
-mod error;
\ No newline at end of file
